@@ -6,9 +6,12 @@ Import the package::
 
 """
 
-__version__ = "0.3.2"  # denote a pre-release for 0.1.0 with 0.1a1
+__version__ = "0.3.3"  # denote a pre-release for 0.1.0 with 0.1a1
 
 from . import db, nox
-from ._artifacts import upload_docs_dir
+from ._artifacts import upload_docs_artifacts
 from ._docs import move_built_docs_to_docs_slash_project_slug
 from ._env import get_package_name, get_schema_handle
+
+# backward compat
+upload_docs_dir = upload_docs_artifacts
